@@ -1,33 +1,39 @@
-from django.db.utils import DatabaseError
+from django.db import DatabaseError
 
 
 class AmbiguityError(Exception):
     """More than one migration matches a name prefix."""
+
     pass
 
 
 class BadMigrationError(Exception):
     """There's a bad migration (unreadable/bad format/etc.)."""
+
     pass
 
 
 class CircularDependencyError(Exception):
     """There's an impossible-to-resolve circular dependency."""
+
     pass
 
 
 class InconsistentMigrationHistory(Exception):
     """An applied migration has some of its dependencies not applied."""
+
     pass
 
 
 class InvalidBasesError(ValueError):
     """A model's base classes can't be resolved."""
+
     pass
 
 
 class IrreversibleError(RuntimeError):
     """An irreversible migration is about to be reversed."""
+
     pass
 
 
